@@ -28,16 +28,16 @@ def _checkSBMLDocument(document):
   if (document.getNumErrors() > 0):
     raise ValueError("Errors in SBML document")
 
-class sbmlModel(object):
+class SbmlModel(object):
 
     """   
-    sbmlModel is used to construct simple models using libSBML methods and
+    SbmlModel is used to construct simple models using libSBML methods and
     print out the model in SBML format.  A user can add species, parameters,
     reactions, events, assignment rules, rate rules, and initial assignments
     to a model.  Then, the user can view the model in SBML format by printing
     the string representation of the class.
 
-    sbmlModel contains two attributes: *document*, an
+    SbmlModel contains two attributes: *document*, an
     `SBMLDocument <http://sbml.org/Software/libSBML/docs/python-api/classlibsbml_1_1_s_b_m_l_document.html>`_
     object, an
     *model*, the
@@ -47,7 +47,7 @@ class sbmlModel(object):
     You can also pass a SBML string and use simlesbml to obtain information about the model
     using the get methods, e.g
        
-    model = simplesbml.sbmlModel (sbmlStr=mySBMLString)
+    model = simplesbml.SbmlModel (sbmlStr=mySBMLString)
     """
 
     def __init__(self, time_units='second', extent_units='mole', \
@@ -117,7 +117,7 @@ class sbmlModel(object):
         """Adds a `Compartment <http://sbml.org/Software/libSBML/docs/python-api/classlibsbml_1_1_compartment.html>`_
         of volume *vol* litres to the model.  The default volume is 1 litre. If the user does
         not specify *comp_id*, the id is set to 'c<n>' where the new compartment
-        is the nth compartment added to the model. All sbmlModel objects are
+        is the nth compartment added to the model. All SbmlModel objects are
         initialized with a default compartment 'c1'."""
 
         c1 = self.model.createCompartment()
@@ -424,6 +424,12 @@ class sbmlModel(object):
         This is not something you need to care about unless you need direct access to libsbml"""
         return self.model
 
+    def getModelId (self):
+        """
+        Returns the SBML Id given to the model. 
+        """
+        return self.model.getModel().getId()
+    
     def getNumCompartments (self):
         """
         Returns the number of compartments in the current model.
@@ -499,9 +505,9 @@ class sbmlModel(object):
         p = self.model.getCompartment(Id)
         if p != None:
            return p.getVolume()
-        raise Exception ('Compartment does not exist')       
-     
+        raise Exception ('Compartment does not exist')         
         
+    # --------------------------------------------------------------
     def getListOfAllSpecies(self):
         """
         Returns a list of **ALL** species Ids in the model
@@ -513,6 +519,28 @@ class sbmlModel(object):
            alist.append (sp.getId())         
         return alist
     
+    def getNthFloatingSpeciesId (self, index):
+        """
+        Returns the Id of the nth floating speces
+        """
+        return self.getListOfFloatingSpecies()[index]
+
+    def getNthBoundarySpeciesId (self, index):
+        """
+        Returns the Id of the nth boundary speces
+        """
+        return self.getListOfBoundarySpecies()[index]
+
+    def getCompartmentIdSpeciesIsIn (self, speciesId):
+        """
+        Returns the compartment Id that the species givenin th argument is in.
+        """
+        sp = self.model.getSpecies(speciesId)
+        if sp != None:
+            return sp.getCompartment()
+        else:
+            raise Exception ('Species Id:' + speciesId + ' does not exist in the model') 
+
     def isSpeciesValueSet (self, Id):
         """
         Returns true if the species has been set a value (concentration or amount).
@@ -584,6 +612,59 @@ class sbmlModel(object):
                alist.append (sp.getId())         
         return alist  
     
+    def isFloatingSpecies (self, Id):
+        """
+        Returns true if the Id is a floating species
+        """
+        sp = self.model.getSpecies(Id)
+        if sp != None:
+           if sp.isSetBoundaryCondition():
+              return False
+           else:
+              return True
+        else:
+           raise Exception ('Id: ' + Id + ' in isFloatingSpecies is not a species Id')  
+
+    def isBoundarySpecies (self, Id):
+        """
+        Returns true if the Id is a boundary species
+        """
+        sp = self.model.getSpecies(Id)
+        if sp != None:
+           if sp.isSetBoundaryCondition():
+              return True
+           else:
+              return False
+        else:
+           raise Exception ('Id: ' + Id + ' in isFloatingSpecies is not a species Id')  
+
+    def isAmount (self, Id):
+        """
+        Returns true if species Id has assigned to it an amount rather then a concentration"
+        """
+        sp = self.model.getSpecies(Id)
+        if sp != None:
+            if sp.isSetInitialAmount():
+                return True
+            else:
+                return False
+        else:
+           raise Exception ('Id: ' + Id + ' in isAmount is not a species Id')  
+
+    def isConcentration (self, Id):
+        """
+        Returns true if species Id has assigned to it a concentration rather then an amount"
+        """
+        sp = self.model.getSpecies(Id)
+        if sp != None:
+            if sp.isSetInitialConcentration():
+                return True
+            else:
+                return False
+        else:
+           raise Exception ('Id: ' + Id + ' in isConcentration is not a species Id')  
+
+
     def getNumFloatingSpecies (self):
         """
         Returns the number of floating species.
@@ -769,6 +850,25 @@ class sbmlModel(object):
         sr = ra.getProduct(productIndex)
         return sr.getStoichiometry ()
         
+    def getNumModifiers (self, reactionId):
+        """
+        Returns the number of modifiers in a given reaction.
+        """
+        return self.model.getReaction (reactionId).getNumModifiers()
+
+    def getListOfModifiers (self, reactionId):
+        """
+        Returns the list of modifiers in a given reaction.
+        """
+        alist = []
+        reaction = self.model.getReaction (reactionId)
+        if reaction != None:
+           for i in range (reaction.getNumModifiers()):
+               alist.append (reaction.getModifer (0))
+           return alist
+        else:
+           raise Exception ('No such reaction can be found:', reactionId)
+ 
     def getListOfRules(self):
         """
         Returns a list of Ids for the rules
@@ -886,6 +986,21 @@ class sbmlModel(object):
         m = eventAss.getMath()
         return libsbml.formulaToL3String(m)
 
+    def getListOfFunctionIds (self):
+        """
+        Returns a list of function definition Ids
+        """
+        alist = []
+        for i in range (self.model.getNumFunctionDefinitions()):
+            alist.append (self.model.getFunctionDefinition (i).getId())
+        return alist
+
+    def getNumFunctionDefinitions(self):
+        """
+        Returns the number of user defined functions in the model
+        """
+        return self.model.getNumFunctionDefinitions()
+
     def getFunctionId (self, index):
         """
         Retuns the Id of the indexth user function definition
